/**
 * @file
 * JavaScript behaviors for AddressFinder location integration.
 */

(function ($, Drupal, drupalSettings) {

  'use strict';

  // @see https://github.com/algolia/places
  // @see https://community.algolia.com/places/documentation.html#options
  Drupal.webform = Drupal.webform || {};
  Drupal.webform.locationAddressFinder = Drupal.webform.locationAddressFinder || {};
  Drupal.webform.locationAddressFinder.options = Drupal.webform.locationAddressFinder.options || {};

  /**
   * Initialize location addressfinder.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.webformLocationAddressFinder = {
    attach: function (context) {

      var mapping = {
        id: 'edit-addressfinder-id',
        full_address: 'edit-addressfinder-full-address',
        street_number_1: 'edit-addressfinder-street-number-1',
        street_number_2: 'edit-addressfinder-street-number-2',
        lot_identifier: 'edit-addressfinder-lot-identifier',
        site_name: 'edit-addressfinder-site-name',
        unit_identifier: 'edit-addressfinder-unit-identifier',
        unit_type: 'edit-addressfinder-unit-type',
        level_number: 'edit-addressfinder-level-number',
        level_type: 'edit-addressfinder-level-type',
        street_name: 'edit-addressfinder-street-name',
        street_type: 'edit-addressfinder-street-type',
        street_suffix: 'edit-addressfinder-street-suffix',
        street: 'edit-addressfinder-street',
        locality_name: 'edit-addressfinder-locality-name',
        state_territory: 'edit-addressfinder-state-territory',
        canonical_address: 'edit-addressfinder-canonical-address',
        canonical_address_id: 'edit-addressfinder-canonical-address-id',
        postcode: 'edit-addressfinder-postcode',
        address_line_1: 'edit-addressfinder-address-line-1',
        address_line_2: 'edit-addressfinder-address-line-2',
        latitude: 'edit-addressfinder-latitude',
        longitude: 'edit-addressfinder-longitude',
        meshblock: 'edit-addressfinder-meshblock',
        meshblock_2016: 'edit-addressfinder-meshblock-2016',
        gnaf_id: 'edit-addressfinder-gnaf-id',
        dpid: 'edit-addressfinder-dpid',
        box_identifier: 'edit-addressfinder-box-identifier',
        box_type: 'edit-addressfinder-box-type',
        legal_parcel_id: 'edit-addressfinder-legal-parcel-id',
      };

      $(context).find('.js-webform-type-webform-location-addressfinder').once('webform-location-addressfinder').each(function () {
        var widget = new AddressFinder.Widget(
          document.getElementById('edit-addressfinder-value'),
          drupalSettings.webform.location.addressfinder.api_key,
          'AU', {
            "address_params": {
              "post_box": "0"
            }
          }
        );
        widget.on('result:select', function (fullAddress, metaData) {
          $.each(mapping, function (source, destination) {
            var e = document.getElementById(destination);
            if (e) {
              var new_value = metaData[source] || '';

              if (new_value == '' && source == 'address_line_1') {
                new_value = metaData['street'];
              }

              e.value = new_value;
            }
          });
        });

        var $element = $(this);
        var $input = $element.find('.webform-location-addressfinder');

        // Prevent the 'Enter' key from submitting the form.
        $input.keydown(function (event) {
          if (event.keyCode === 13) {
            event.preventDefault();
          }
        });

        // Disable autocomplete.
        var isChrome = /Chrome/.test(window.navigator.userAgent) && /Google Inc/.test(window.navigator.vendor);
        $input.attr('autocomplete', (isChrome) ? 'nothanks' : 'false');
      });
    }
  };

})(jQuery, Drupal, drupalSettings);
